@@ -33,9 +33,10 @@
 #  define LIBKMAHJONGG_DEPRECATED_NO_EXPORT LIBKMAHJONGG_NO_EXPORT LIBKMAHJONGG_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define LIBKMAHJONGG_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef LIBKMAHJONGG_NO_DEPRECATED
+#    define LIBKMAHJONGG_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
